==> bow-ui-1.2-sources.jar: org/chorem/bow/BowBookmark.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyAuthorisation;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyLabel;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface BowBookmark extends BusinessEntity, WikittyLabel, WikittyAuthorisation {

    String EXT_BOWBOOKMARK = "BowBookmark";

    String FIELD_BOWBOOKMARK_LINK = "link";

    String FQ_FIELD_BOWBOOKMARK_LINK = EXT_BOWBOOKMARK + ".link";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_LINK = new ElementField(FQ_FIELD_BOWBOOKMARK_LINK);

    String FIELD_BOWBOOKMARK_DESCRIPTION = "description";

    String FQ_FIELD_BOWBOOKMARK_DESCRIPTION = EXT_BOWBOOKMARK + ".description";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_DESCRIPTION = new ElementField(FQ_FIELD_BOWBOOKMARK_DESCRIPTION);

    String FIELD_BOWBOOKMARK_CREATIONDATE = "creationDate";

    String FQ_FIELD_BOWBOOKMARK_CREATIONDATE = EXT_BOWBOOKMARK + ".creationDate";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_CREATIONDATE = new ElementField(FQ_FIELD_BOWBOOKMARK_CREATIONDATE);

    String FIELD_BOWBOOKMARK_CLICK = "click";

    String FQ_FIELD_BOWBOOKMARK_CLICK = EXT_BOWBOOKMARK + ".click";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_CLICK = new ElementField(FQ_FIELD_BOWBOOKMARK_CLICK);

    String FIELD_BOWBOOKMARK_PRIVATEALIAS = "privateAlias";

    String FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS = EXT_BOWBOOKMARK + ".privateAlias";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_PRIVATEALIAS = new ElementField(FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS);

    String FIELD_BOWBOOKMARK_PUBLICALIAS = "publicAlias";

    String FQ_FIELD_BOWBOOKMARK_PUBLICALIAS = EXT_BOWBOOKMARK + ".publicAlias";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_PUBLICALIAS = new ElementField(FQ_FIELD_BOWBOOKMARK_PUBLICALIAS);

    String FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = "authentificationInfo";

    String FQ_FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = EXT_BOWBOOKMARK + ".authentificationInfo";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = new ElementField(FQ_FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO);

    String getLink();

    void setLink(String link);

    String getDescription();

    void setDescription(String description);

    Date getCreationDate();

    void setCreationDate(Date creationDate);

    int getClick();

    void setClick(int click);

    String getPrivateAlias();

    void setPrivateAlias(String privateAlias);

    String getPublicAlias();

    void setPublicAlias(String publicAlias);

    String getAuthentificationInfo();

    void setAuthentificationInfo(String authentificationInfo);

} //BowBookmark

==> bow-ui-1.4.1-sources.jar: org/chorem/bow/BowBookmark.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyAuthorisation;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyLabel;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface BowBookmark extends BusinessEntity, WikittyLabel, WikittyAuthorisation {

    String EXT_BOWBOOKMARK = "BowBookmark";

    String FIELD_BOWBOOKMARK_LINK = "link";

    String FQ_FIELD_BOWBOOKMARK_LINK = EXT_BOWBOOKMARK + ".link";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_LINK = new ElementField(FQ_FIELD_BOWBOOKMARK_LINK);

    String FIELD_BOWBOOKMARK_DESCRIPTION = "description";

    String FQ_FIELD_BOWBOOKMARK_DESCRIPTION = EXT_BOWBOOKMARK + ".description";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_DESCRIPTION = new ElementField(FQ_FIELD_BOWBOOKMARK_DESCRIPTION);

    String FIELD_BOWBOOKMARK_CREATIONDATE = "creationDate";

    String FQ_FIELD_BOWBOOKMARK_CREATIONDATE = EXT_BOWBOOKMARK + ".creationDate";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_CREATIONDATE = new ElementField(FQ_FIELD_BOWBOOKMARK_CREATIONDATE);

    String FIELD_BOWBOOKMARK_CLICK = "click";

    String FQ_FIELD_BOWBOOKMARK_CLICK = EXT_BOWBOOKMARK + ".click";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_CLICK = new ElementField(FQ_FIELD_BOWBOOKMARK_CLICK);

    String FIELD_BOWBOOKMARK_PRIVATEALIAS = "privateAlias";

    String FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS = EXT_BOWBOOKMARK + ".privateAlias";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_PRIVATEALIAS = new ElementField(FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS);

    String FIELD_BOWBOOKMARK_PUBLICALIAS = "publicAlias";

    String FQ_FIELD_BOWBOOKMARK_PUBLICALIAS = EXT_BOWBOOKMARK + ".publicAlias";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_PUBLICALIAS = new ElementField(FQ_FIELD_BOWBOOKMARK_PUBLICALIAS);

    String FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = "authentificationInfo";

    String FQ_FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = EXT_BOWBOOKMARK + ".authentificationInfo";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = new ElementField(FQ_FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO);

    String FIELD_BOWBOOKMARK_FAVICON = "favicon";

    String FQ_FIELD_BOWBOOKMARK_FAVICON = EXT_BOWBOOKMARK + ".favicon";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_FAVICON = new ElementField(FQ_FIELD_BOWBOOKMARK_FAVICON);

    String FIELD_BOWBOOKMARK_SCREENSHOT = "screenshot";

    String FQ_FIELD_BOWBOOKMARK_SCREENSHOT = EXT_BOWBOOKMARK + ".screenshot";

    ElementField ELEMENT_FIELD_BOWBOOKMARK_SCREENSHOT = new ElementField(FQ_FIELD_BOWBOOKMARK_SCREENSHOT);

    String getLink();

    void setLink(String link);

    String getDescription();

    void setDescription(String description);

    Date getCreationDate();

    void setCreationDate(Date creationDate);

    int getClick();

    void setClick(int click);

    String getPrivateAlias();

    void setPrivateAlias(String privateAlias);

    String getPublicAlias();

    void setPublicAlias(String publicAlias);

    String getAuthentificationInfo();

    void setAuthentificationInfo(String authentificationInfo);

    byte[] getFavicon();

    void setFavicon(byte[] favicon);

    byte[] getScreenshot();

    void setScreenshot(byte[] screenshot);

} //BowBookmark
